@@ -55,6 +55,8 @@ enum class IAMErrors {
   DUPLICATE_S_S_H_PUBLIC_KEY,
   ENTITY_ALREADY_EXISTS,
   ENTITY_TEMPORARILY_UNMODIFIABLE,
+  FEATURE_DISABLED,
+  FEATURE_ENABLED,
   INVALID_AUTHENTICATION_CODE,
   INVALID_CERTIFICATE,
   INVALID_INPUT,
